@@ -52,10 +52,10 @@ use 5.008;
 use strict;
 use warnings;
 use Carp                   ();
-use File::Spec        3.29 ();
 use Parse::CPAN::Meta 1.39 ();
+use Portable::FileSpec;
 
-our $VERSION = '1.18';
+our $VERSION = '1.19';
 
 # This variable is provided exclusively for the
 # use of test scripts.
@@ -185,14 +185,14 @@ sub default {
 	# G:\\strawberry\\perl\\bin\\perl.exe
 	# Split it up, and search upwards to try and locate the
 	# portable.perl file in the distribution root.
-	my ($dist_volume, $d, $f) = File::Spec->splitpath($perlpath);
-	my @d = File::Spec->splitdir($d);
+	my ($dist_volume, $d, $f) = Portable::FileSpec::splitpath($perlpath);
+	my @d = Portable::FileSpec::splitdir($d);
 	pop @d if @d > 0 && $d[-1] eq '';
 	my @tmp = grep {
-			-f File::Spec->catpath( $dist_volume, $_, 'portable.perl' )
+			-f Portable::FileSpec::catpath( $dist_volume, $_, 'portable.perl' )
 		}
 		map {
-			File::Spec->catdir(@d[0 .. $_])
+			Portable::FileSpec::catdir(@d[0 .. $_])
 		} reverse ( 0 .. $#d );
 	my $dist_dirs = $tmp[0];
 	unless ( defined $dist_dirs ) {
@@ -200,8 +200,8 @@ sub default {
 	}
 
 	# Derive the main paths from the plain dirs
-	my $dist_root = File::Spec->catpath($dist_volume, $dist_dirs, '' );
-	my $conf      = File::Spec->catpath($dist_volume, $dist_dirs, 'portable.perl' );
+	my $dist_root = Portable::FileSpec::catpath($dist_volume, $dist_dirs, '' );
+	my $conf      = Portable::FileSpec::catpath($dist_volume, $dist_dirs, 'portable.perl' );
 
 	# Load the YAML file
 	my $portable = Parse::CPAN::Meta::LoadFile( $conf );
